package cn.com.infosec.x509;

import cn.com.infosec.asn1.ASN1EncodableVector;
import cn.com.infosec.asn1.ASN1InputStream;
import cn.com.infosec.asn1.ASN1Sequence;
import cn.com.infosec.asn1.DERBitString;
import cn.com.infosec.asn1.DEREncodable;
import cn.com.infosec.asn1.DERGeneralizedTime;
import cn.com.infosec.asn1.DERInteger;
import cn.com.infosec.asn1.DERObjectIdentifier;
import cn.com.infosec.asn1.DERSequence;
import cn.com.infosec.asn1.x509.AlgorithmIdentifier;
import cn.com.infosec.asn1.x509.CertificateList;
import cn.com.infosec.asn1.x509.TBSCertList;
import cn.com.infosec.asn1.x509.Time;
import cn.com.infosec.asn1.x509.V2TBSCertListGenerator;
import cn.com.infosec.asn1.x509.X509Extensions;
import cn.com.infosec.asn1.x509.X509ExtensionsGenerator;
import cn.com.infosec.asn1.x509.X509Name;
import cn.com.infosec.jce.X509Principal;
import cn.com.infosec.jce.provider.X509CRLObject;
import java.io.IOException;
import java.math.BigInteger;
import java.security.GeneralSecurityException;
import java.security.InvalidKeyException;
import java.security.NoSuchProviderException;
import java.security.PrivateKey;
import java.security.SecureRandom;
import java.security.SignatureException;
import java.security.cert.CRLException;
import java.security.cert.X509CRL;
import java.security.cert.X509CRLEntry;
import java.util.Date;
import java.util.Iterator;
import java.util.Set;
import javax.security.auth.x500.X500Principal;

public class X509V2CRLGenerator {
   private V2TBSCertListGenerator tbsGen;
   private DERObjectIdentifier sigOID;
   private AlgorithmIdentifier sigAlgId;
   private String signatureAlgorithm;
   private X509ExtensionsGenerator extGenerator;

   public X509V2CRLGenerator() {
      X509V2CRLGenerator var10000 = this;
      X509V2CRLGenerator var10001 = this;
      super();
      V2TBSCertListGenerator var1;
      var1 = new V2TBSCertListGenerator.<init>();
      var10001.tbsGen = var1;
      X509ExtensionsGenerator var2;
      var2 = new X509ExtensionsGenerator.<init>();
      var10000.extGenerator = var2;
   }

   private TBSCertList generateCertList() {
      if (!this.extGenerator.isEmpty()) {
         this.tbsGen.setExtensions(this.extGenerator.generate());
      }

      return this.tbsGen.generateTBSCertList();
   }

   private X509CRL generateJcaObject(TBSCertList tbsCrl, byte[] signature) {
      ASN1EncodableVector var3;
      ASN1EncodableVector var10000 = var3 = new ASN1EncodableVector;
      var3.<init>();
      var3.add(tbsCrl);
      var10000.add(this.sigAlgId);
      var10000.add(new DERBitString(signature));
      return new X509CRLObject(new CertificateList(new DERSequence(var3)));
   }

   public void reset() {
      this.tbsGen = new V2TBSCertListGenerator();
      this.extGenerator.reset();
   }

   public void setIssuerDN(X500Principal issuer) {
      try {
         this.tbsGen.setIssuer(new X509Principal(issuer.getEncoded()));
      } catch (IOException var2) {
         throw new IllegalArgumentException("can't process principal: " + var2);
      }
   }

   public void setIssuerDN(X509Name issuer) {
      this.tbsGen.setIssuer(issuer);
   }

   public void setThisUpdate(Date date) {
      this.tbsGen.setThisUpdate(new Time(date));
   }

   public void setNextUpdate(Date date) {
      this.tbsGen.setNextUpdate(new Time(date));
   }

   public void addCRLEntry(BigInteger userCertificate, Date revocationDate, int reason) {
      V2TBSCertListGenerator var10000 = this.tbsGen;
      DERInteger var10001 = new DERInteger(userCertificate);
      Time var4;
      var4 = new Time.<init>(revocationDate);
      var10000.addCRLEntry(var10001, var4, reason);
   }

   public void addCRLEntry(BigInteger userCertificate, Date revocationDate, int reason, Date invalidityDate) {
      V2TBSCertListGenerator var10000 = this.tbsGen;
      DERInteger var10001 = new DERInteger(userCertificate);
      Time var5;
      var5 = new Time.<init>(revocationDate);
      DERGeneralizedTime userCertificate1;
      userCertificate1 = new DERGeneralizedTime.<init>(invalidityDate);
      var10000.addCRLEntry(var10001, var5, reason, userCertificate1);
   }

   public void addCRLEntry(BigInteger userCertificate, Date revocationDate, X509Extensions extensions) {
      V2TBSCertListGenerator var10000 = this.tbsGen;
      DERInteger var10001 = new DERInteger(userCertificate);
      Time var4;
      var4 = new Time.<init>(revocationDate);
      var10000.addCRLEntry(var10001, var4, extensions);
   }

   public void addCRL(X509CRL other) {
      Set other1;
      if ((other1 = other.getRevokedCertificates()) != null) {
         Iterator other2 = other1.iterator();

         while(other2.hasNext()) {
            X509V2CRLGenerator var10000 = this;
            X509CRLEntry var2 = (X509CRLEntry)other2.next();
            ASN1InputStream var3;
            var3 = new ASN1InputStream.<init>(var2.getEncoded());

            try {
               var10000.tbsGen.addCRLEntry(ASN1Sequence.getInstance(var3.readObject()));
            } catch (IOException var4) {
               throw new CRLException("exception processing encoding of CRL: " + var4.toString());
            }
         }
      }

   }

   public void setSignatureAlgorithm(String signatureAlgorithm) {
      X509V2CRLGenerator var10000 = this;
      String var10002 = this.signatureAlgorithm = signatureAlgorithm;

      boolean var10001;
      DERObjectIdentifier var6;
      try {
         var6 = X509Util.getAlgorithmOID(var10002);
      } catch (Exception var4) {
         var10001 = false;
         throw new IllegalArgumentException("Unknown signature type requested");
      }

      DERObjectIdentifier var2 = var6;

      String var10003;
      try {
         var10003 = signatureAlgorithm;
         this.sigOID = var2;
      } catch (Exception var3) {
         var10001 = false;
         throw new IllegalArgumentException("Unknown signature type requested");
      }

      AlgorithmIdentifier var5;
      this.sigAlgId = var5 = X509Util.getSigAlgID(var6, var10003);
      var10000.tbsGen.setSignature(var5);
   }

   public void addExtension(String oid, boolean critical, DEREncodable value) {
      X509V2CRLGenerator var10000 = this;
      DERObjectIdentifier var4;
      var4 = new DERObjectIdentifier.<init>(oid);
      var10000.addExtension(var4, critical, value);
   }

   public void addExtension(DERObjectIdentifier oid, boolean critical, DEREncodable value) {
      this.extGenerator.addExtension(oid, critical, value);
   }

   public void addExtension(String oid, boolean critical, byte[] value) {
      X509V2CRLGenerator var10000 = this;
      DERObjectIdentifier var4;
      var4 = new DERObjectIdentifier.<init>(oid);
      var10000.addExtension(var4, critical, value);
   }

   public void addExtension(DERObjectIdentifier oid, boolean critical, byte[] value) {
      this.extGenerator.addExtension(oid, critical, value);
   }

   /** @deprecated */
   public X509CRL generateX509CRL(PrivateKey key) {
      try {
         return this.generateX509CRL(key, "INFOSEC", (SecureRandom)null);
      } catch (NoSuchProviderException var2) {
         throw new SecurityException("BC provider not installed!");
      }
   }

   /** @deprecated */
   public X509CRL generateX509CRL(PrivateKey key, SecureRandom random) {
      try {
         return this.generateX509CRL(key, "INFOSEC", random);
      } catch (NoSuchProviderException var3) {
         throw new SecurityException("BC provider not installed!");
      }
   }

   /** @deprecated */
   public X509CRL generateX509CRL(PrivateKey key, String provider) {
      return this.generateX509CRL(key, provider, (SecureRandom)null);
   }

   /** @deprecated */
   public X509CRL generateX509CRL(PrivateKey key, String provider, SecureRandom random) {
      try {
         return this.generate(key, provider, random);
      } catch (NoSuchProviderException var4) {
         throw var4;
      } catch (SignatureException var5) {
         throw var5;
      } catch (InvalidKeyException var6) {
         throw var6;
      } catch (GeneralSecurityException var7) {
         throw new SecurityException("exception: " + var7);
      }
   }

   public X509CRL generate(PrivateKey key) {
      return this.generate(key, (SecureRandom)null);
   }

   public X509CRL generate(PrivateKey param1, SecureRandom param2) {
      // $FF: Couldn't be decompiled
   }

   public X509CRL generate(PrivateKey key, String provider) {
      return this.generate(key, provider, (SecureRandom)null);
   }

   public X509CRL generate(PrivateKey param1, String param2, SecureRandom param3) {
      // $FF: Couldn't be decompiled
   }

   public Iterator getSignatureAlgNames() {
      return X509Util.getAlgNames();
   }

   private static class ExtCRLException extends CRLException {
      Throwable cause;

      ExtCRLException(String message, Throwable cause) {
         super(message);
         this.cause = cause;
      }

      public Throwable getCause() {
         return this.cause;
      }
   }
}
